@@ -2,9 +2,10 @@ package Plagger::Feed;
 use strict;
 
 use base qw( Class::Accessor::Fast );
-__PACKAGE__->mk_accessors(qw( link url image description language author updated tags meta type ));
+__PACKAGE__->mk_accessors(qw( link url image description language author updated tags meta type source_xml ));
 
 use Digest::MD5 qw(md5_hex);
+use Plagger::Util;
 
 sub new {
     my $class = shift;
@@ -21,6 +22,12 @@ sub add_entry {
     push @{ $self->{entries} }, $entry;
 }
 
+sub delete_entry {
+    my($self, $entry) = @_;
+    my @entries = grep { $_ ne $entry } $self->entries;
+    $self->{entries} = \@entries;
+}
+
 sub entries {
     my $self = shift;
     wantarray ? @{ $self->{entries} } : $self->{entries};
@@ -47,4 +54,9 @@ sub id {
     $self->{id} || Digest::MD5::md5_hex($self->url || $self->link);
 }
 
+sub title_text {
+    my $self = shift;
+    Plagger::Util::strip_html($self->title);
+}
+
 1;
